.. _Digital Rock api:

Digital Rock
============

.. automodule:: rockverse.digitalrock

.. toctree::
    :maxdepth: 2

    digitalrock/voxelimage


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
